==> nezha-compute-common-1.27.1002-20181227.121147-1-sources.jar: cn/com/duiba/nezha/compute/common/model/activityselectconversionforms/ActivityInfoModel.java <==
package cn.com.duiba.nezha.compute.common.model.activityselectconversionforms;

public class ActivityInfoModel {
    long activityId;
    long slotId;
    long appId;
    double changeScore;
    Val hisRequest;
    Val hisClick;
    Val hisSend;
    Val hisCost;
    Val lastRequest;
    Val lastClick;
    Val lastSend;
    Val lastCost;

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public Val getLastRequest() {
        return lastRequest;
    }

    public void setLastRequest(Val lastRequest) {
        this.lastRequest = lastRequest;
    }

    public Val getLastClick() {
        return lastClick;
    }

    public void setLastClick(Val lastClick) {
        this.lastClick = lastClick;
    }

    public Val getLastSend() {
        return lastSend;
    }

    public void setLastSend(Val lastSend) {
        this.lastSend = lastSend;
    }

    public Val getLastCost() {
        return lastCost;
    }

    public void setLastCost(Val lastCost) {
        this.lastCost = lastCost;
    }
}

==> nezha-compute-common-1.27.1004-20190110.074747-1-sources.jar: cn/com/duiba/nezha/compute/common/model/activityselectconversionforms/ActivityInfoModel.java <==
package cn.com.duiba.nezha.compute.common.model.activityselectconversionforms;

public class ActivityInfoModel {
    long activityId;
    long slotId;
    long appId;
    double changeScore;
    Val hisRequest;
    Val hisClick;
    Val hisSend;
    Val hisCost;
    Val lastRequest;
    Val lastClick;
    Val lastSend;
    Val lastCost;
    ActivityChangeVal activityChangeVal;

    public ActivityChangeVal getActivityChangeVal() {
        return activityChangeVal;
    }

    public void setActivityChangeVal(ActivityChangeVal activityChangeVal) {
        this.activityChangeVal = activityChangeVal;
    }



    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public Val getLastRequest() {
        return lastRequest;
    }

    public void setLastRequest(Val lastRequest) {
        this.lastRequest = lastRequest;
    }

    public Val getLastClick() {
        return lastClick;
    }

    public void setLastClick(Val lastClick) {
        this.lastClick = lastClick;
    }

    public Val getLastSend() {
        return lastSend;
    }

    public void setLastSend(Val lastSend) {
        this.lastSend = lastSend;
    }

    public Val getLastCost() {
        return lastCost;
    }

    public void setLastCost(Val lastCost) {
        this.lastCost = lastCost;
    }
}
